@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
+This document describes version 0.05 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -49,86 +49,40 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.03
+L<Perl::Examples::Accessors::Array> 0.04
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.03
+L<Perl::Examples::Accessors::ClassAccessor> 0.04
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.03
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.03
+L<Perl::Examples::Accessors::ClassInsideOut> 0.04
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.03
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
 
-L<Perl::Examples::Accessors::Hash> 0.03
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
 
-L<Perl::Examples::Accessors::Mo> 0.03
+L<Perl::Examples::Accessors::Hash> 0.04
 
-L<Perl::Examples::Accessors::Moo> 0.03
+L<Perl::Examples::Accessors::Mo> 0.04
 
-L<Perl::Examples::Accessors::Moose> 0.03
+L<Perl::Examples::Accessors::Moo> 0.04
 
-L<Perl::Examples::Accessors::Mouse> 0.03
+L<Perl::Examples::Accessors::Moose> 0.04
 
-L<Perl::Examples::Accessors::Scalar> 0.03
+L<Perl::Examples::Accessors::Mouse> 0.04
+
+L<Perl::Examples::Accessors::Scalar> 0.04
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Perl::Examples::Accessors::Moo (perl_code)
-
-L<Perl::Examples::Accessors::Moo>
-
-
-
 =item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
 
 L<Perl::Examples::Accessors::ClassXSAccessorArray>
 
 
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
-
-L<Perl::Examples::Accessors::Mo>
-
-
-
-=item * Perl::Examples::Accessors::Mouse (perl_code)
-
-L<Perl::Examples::Accessors::Mouse>
-
-
-
-=item * Perl::Examples::Accessors::Scalar (perl_code)
-
-L<Perl::Examples::Accessors::Scalar>
-
-
-
-=item * Perl::Examples::Accessors::Moose (perl_code)
-
-L<Perl::Examples::Accessors::Moose>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
-
-
-
-=item * Perl::Examples::Accessors::Array (perl_code)
-
-L<Perl::Examples::Accessors::Array>
-
-
-
-=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessor>
-
-
-
 =item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
 
 L<Perl::Examples::Accessors::ClassAccessorArray>
@@ -141,29 +95,84 @@ L<Perl::Examples::Accessors::ClassAccessor>
 
 
 
+=item * Perl::Examples::Accessors::Moo (perl_code)
+
+L<Perl::Examples::Accessors::Moo>
+
+
+
+=item * Perl::Examples::Accessors::Hash (perl_code)
+
+L<Perl::Examples::Accessors::Hash>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessor>
+
+
+
+=item * Perl::Examples::Accessors::Mouse (perl_code)
+
+L<Perl::Examples::Accessors::Mouse>
+
+
+
+=item * Perl::Examples::Accessors::Array (perl_code)
+
+L<Perl::Examples::Accessors::Array>
+
+
+
+=item * Perl::Examples::Accessors::Moose (perl_code)
+
+L<Perl::Examples::Accessors::Moose>
+
+
+
+=item * Perl::Examples::Accessors::Scalar (perl_code)
+
+L<Perl::Examples::Accessors::Scalar>
+
+
+
+=item * Perl::Examples::Accessors::Mo (perl_code)
+
+L<Perl::Examples::Accessors::Mo>
+
+
+
+=item * Perl::Examples::Accessors::ClassInsideOut (perl_code)
+
+L<Perl::Examples::Accessors::ClassInsideOut>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
 
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | Perl::Examples::Accessors::Moose                | 1.8e+02   | 175                    | 1          | 0.00066 | 20      |
- | Perl::Examples::Accessors::Moo                  | 32        | 27                     | 5.7        | 9e-05   | 20      |
- | Perl::Examples::Accessors::Mouse                | 26        | 21                     | 6.9        | 6.4e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessorArray | 12        | 7                      | 15         | 9e-05   | 20      |
- | Perl::Examples::Accessors::ClassAccessor        | 12        | 7                      | 15         | 7.9e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessor      | 12        | 7                      | 15         | 8.1e-05 | 21      |
- | Perl::Examples::Accessors::ClassAccessorArray   | 7         | 2                      | 26         | 6.1e-05 | 20      |
- | Perl::Examples::Accessors::Mo                   | 6.8       | 1.8                    | 27         | 4.4e-05 | 20      |
- | Perl::Examples::Accessors::Scalar               | 5         | 0                      | 4e+01      | 7.3e-05 | 20      |
- | Perl::Examples::Accessors::Hash                 | 5         | 0                      | 4e+01      | 5.9e-05 | 20      |
- | Perl::Examples::Accessors::Array                | 4.7       | -0.3                   | 39         | 4.5e-05 | 20      |
- | perl -e1 (baseline)                             | 5         | 0                      | 4e+01      | 8.2e-05 | 20      |
+ | Perl::Examples::Accessors::Moose                | 114       | 111.5                  | 1          | 0.00011 | 20      |
+ | Perl::Examples::Accessors::Moo                  | 21        | 18.5                   | 5.3        | 4.3e-05 | 22      |
+ | Perl::Examples::Accessors::Mouse                | 17        | 14.5                   | 6.6        | 7.3e-05 | 20      |
+ | Perl::Examples::Accessors::ClassInsideOut       | 10        | 7.5                    | 11         | 1.1e-05 | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessorArray | 7.9       | 5.4                    | 14         | 2e-05   | 20      |
+ | Perl::Examples::Accessors::ClassAccessor        | 7.5       | 5                      | 15         | 1.8e-05 | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessor      | 7.4       | 4.9                    | 15         | 1.7e-05 | 20      |
+ | Perl::Examples::Accessors::Mo                   | 4.1       | 1.6                    | 28         | 1e-05   | 20      |
+ | Perl::Examples::Accessors::ClassAccessorArray   | 4.1       | 1.6                    | 28         | 1.5e-05 | 20      |
+ | Perl::Examples::Accessors::Array                | 2.8       | 0.3                    | 40         | 1.6e-05 | 20      |
+ | Perl::Examples::Accessors::Hash                 | 2.8       | 0.3                    | 40         | 2e-05   | 20      |
+ | Perl::Examples::Accessors::Scalar               | 2.7       | 0.2                    | 42         | 1.1e-05 | 20      |
+ | perl -e1 (baseline)                             | 2.5       | 0                      | 45         | 4.5e-06 | 20      |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
