@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -10,6 +10,7 @@ my $classes = \%Bencher::ScenarioUtil::Accessors::classes;
 our $scenario = {
     summary => 'Benchmark object construction',
     modules => {
+        'Perl::Examples::Accessors' => {version=>0.04},
     },
     participants => [
         map {
@@ -39,7 +40,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
+This document describes version 0.05 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -57,40 +58,36 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Perl::Examples::Accessors::Array> 0.03
+L<Perl::Examples::Accessors> 0.04
 
-L<Perl::Examples::Accessors::ClassAccessor> 0.03
+L<Perl::Examples::Accessors::Array> 0.04
 
-L<Perl::Examples::Accessors::ClassAccessorArray> 0.03
+L<Perl::Examples::Accessors::ClassAccessor> 0.04
 
-L<Perl::Examples::Accessors::ClassXSAccessor> 0.03
+L<Perl::Examples::Accessors::ClassAccessorArray> 0.04
 
-L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.03
+L<Perl::Examples::Accessors::ClassInsideOut> 0.04
 
-L<Perl::Examples::Accessors::Hash> 0.03
+L<Perl::Examples::Accessors::ClassXSAccessor> 0.04
 
-L<Perl::Examples::Accessors::Mo> 0.03
+L<Perl::Examples::Accessors::ClassXSAccessorArray> 0.04
 
-L<Perl::Examples::Accessors::Moo> 0.03
+L<Perl::Examples::Accessors::Hash> 0.04
 
-L<Perl::Examples::Accessors::Moose> 0.03
+L<Perl::Examples::Accessors::Mo> 0.04
 
-L<Perl::Examples::Accessors::Mouse> 0.03
+L<Perl::Examples::Accessors::Moo> 0.04
 
-L<Perl::Examples::Accessors::Scalar> 0.03
+L<Perl::Examples::Accessors::Moose> 0.04
+
+L<Perl::Examples::Accessors::Mouse> 0.04
+
+L<Perl::Examples::Accessors::Scalar> 0.04
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Moo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moo->new
-
-
-
 =item * Class::XSAccessor::Array (perl_code)
 
 Code template:
@@ -99,62 +96,6 @@ Code template:
 
 
 
-=item * Mo (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mo->new
-
-
-
-=item * Mouse (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Mouse->new
-
-
-
-=item * no generator (scalar-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Moose (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Moose->new
-
-
-
-=item * no generator (hash-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * no generator (array-based) (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
-
-
-
-=item * Class::XSAccessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessor->new
-
-
-
 =item * Class::Accessor::Array (perl_code)
 
 Code template:
@@ -171,29 +112,102 @@ Code template:
 
 
 
+=item * Moo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moo->new
+
+
+
+=item * no generator (hash-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Hash->new
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessor->new
+
+
+
+=item * Mouse (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mouse->new
+
+
+
+=item * no generator (array-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * Moose (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Moose->new
+
+
+
+=item * no generator (scalar-based) (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
+=item * Class::InsideOut (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassInsideOut->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | participant                 | rate (/s) | time (μs) | vs_slowest | result_size (b) | errors  | samples |
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
- | Moose                       | 4.6e+05   | 2.2       | 1          | 120             | 4.2e-09 | 20      |
- | Mo                          | 7.35e+05  | 1.36      | 1.58       | 120             | 1.3e-09 | 20      |
- | Moo                         | 9.22e+05  | 1.08      | 1.98       | 120             | 4e-10   | 23      |
- | Class::Accessor             | 1.1e+06   | 0.95      | 2.3        | 120             | 1.7e-09 | 20      |
- | Mouse                       | 1.29e+06  | 0.776     | 2.77       | 120             | 4.1e-10 | 21      |
- | no generator (array-based)  | 1.65e+06  | 0.608     | 3.54       | 64              | 2.9e-10 | 20      |
- | no generator (hash-based)   | 2e+06     | 0.51      | 4.2        | 120             | 9.9e-10 | 22      |
- | no generator (scalar-based) | 2.02e+06  | 0.496     | 4.34       | 72              | 2.1e-10 | 20      |
- | Class::Accessor::Array      | 2.08e+06  | 0.482     | 4.46       | 64              | 2.1e-10 | 20      |
- | Class::XSAccessor::Array    | 3.2e+06   | 0.312     | 6.89       | 64              | 8.3e-11 | 20      |
- | Class::XSAccessor           | 3.21e+06  | 0.311     | 6.91       | 120             | 9.2e-11 | 22      |
- +-----------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
+ | participant                 | rate (/s)   | time (μs) | vs_slowest | result_size (b) | errors  | samples |
+ +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
+ | Class::InsideOut            | 3.9e+05     | 2.6       | 1          | 144             | 3.3e-09 | 20      |
+ | Moose                       | 9.2495e+05  | 1.0811    | 2.3846     | 120             | 9.2e-12 | 22      |
+ | Mo                          | 1.3e+06     | 0.77      | 3.4        | 120             | 1.7e-09 | 20      |
+ | Moo                         | 1.667e+06   | 0.5998    | 4.298      | 120             | 1.1e-11 | 20      |
+ | Class::Accessor             | 1.81e+06    | 0.5525    | 4.667      | 120             | 1e-11   | 20      |
+ | Mouse                       | 2.06e+06    | 0.485     | 5.31       | 120             | 1.8e-10 | 26      |
+ | no generator (array-based)  | 2.54975e+06 | 0.392196  | 6.57354    | 64              | 0       | 20      |
+ | no generator (hash-based)   | 3.033e+06   | 0.3297    | 7.821      | 120             | 1.2e-11 | 20      |
+ | no generator (scalar-based) | 3.37e+06    | 0.297     | 8.69       | 72              | 1e-10   | 22      |
+ | Class::Accessor::Array      | 3.45e+06    | 0.29      | 8.89       | 64              | 8.6e-11 | 30      |
+ | Class::XSAccessor           | 5.125e+06   | 0.1951    | 13.21      | 120             | 9.4e-12 | 20      |
+ | Class::XSAccessor::Array    | 5.26e+06    | 0.19      | 13.6       | 64              | 1e-10   | 20      |
+ +-----------------------------+-------------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
 
