@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-31.
+This document describes version 0.05 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -53,6 +53,8 @@ L<Class::Accessor> 0.34
 
 L<Class::Accessor::Array> 0.02
 
+L<Class::InsideOut> 1.13
+
 L<Class::XSAccessor> 1.19
 
 L<Class::XSAccessor::Array> 1.19
@@ -61,29 +63,45 @@ L<Mo> 0.39
 
 L<Moo> 2.000002
 
-L<Moose> 2.1604
+L<Moose> 2.1405
 
-L<Mouse> v2.4.5
+L<Mouse> 2.4.2
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Moo (perl_code)
-
-L<Moo>
-
-
-
 =item * Class::XSAccessor::Array (perl_code)
 
 L<Class::XSAccessor::Array>
 
 
 
-=item * Mo (perl_code)
+=item * Class::Accessor::Array (perl_code)
 
-L<Mo>
+L<Class::Accessor::Array>
+
+
+
+=item * Class::Accessor (perl_code)
+
+L<Class::Accessor>
+
+
+
+=item * Moo (perl_code)
+
+L<Moo>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Class::XSAccessor (perl_code)
+
+L<Class::XSAccessor>
 
 
 
@@ -107,25 +125,15 @@ L<Moose>
 
 
 
-=item *  (perl_code)
+=item * Mo (perl_code)
+
+L<Mo>
 
 
 
-=item * Class::XSAccessor (perl_code)
+=item * Class::InsideOut (perl_code)
 
-L<Class::XSAccessor>
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-L<Class::Accessor::Array>
-
-
-
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
+L<Class::InsideOut>
 
 
 
@@ -133,22 +141,23 @@ L<Class::Accessor>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
 
  +--------------------------+-----------+------------------------+------------+---------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +--------------------------+-----------+------------------------+------------+---------+---------+
- | Moose                    | 1.7e+02   | 165.7                  | 1          | 0.00043 | 20      |
- | Mouse                    | 26        | 21.7                   | 6.6        | 0.00012 | 20      |
- | Moo                      | 20        | 15.7                   | 8.5        | 0.00012 | 20      |
- | Class::XSAccessor::Array | 12        | 7.7                    | 14         | 8.1e-05 | 20      |
- | Class::Accessor          | 12        | 7.7                    | 14         | 6.2e-05 | 20      |
- | Class::XSAccessor        | 12        | 7.7                    | 15         | 5.6e-05 | 20      |
- | Mo                       | 6.8       | 2.5                    | 25         | 5.5e-05 | 20      |
- | Class::Accessor::Array   | 6.6       | 2.3                    | 26         | 1.8e-05 | 20      |
- | perl -e1 (baseline)      | 4.3       | 0                      | 40         | 2.9e-05 | 20      |
+ | Moose                    | 1.1e+02   | 107.4                  | 1          | 0.00013 | 20      |
+ | Mouse                    | 18        | 15.4                   | 6.3        | 8.5e-05 | 20      |
+ | Moo                      | 14        | 11.4                   | 7.8        | 3.3e-05 | 20      |
+ | Class::InsideOut         | 11        | 8.4                    | 10         | 3.1e-05 | 23      |
+ | Class::XSAccessor::Array | 7.7       | 5.1                    | 14         | 2.7e-05 | 20      |
+ | Class::Accessor          | 7.4       | 4.8                    | 15         | 1.8e-05 | 20      |
+ | Class::XSAccessor        | 7.3       | 4.7                    | 15         | 9.8e-06 | 22      |
+ | Mo                       | 4.2       | 1.6                    | 26         | 3e-05   | 20      |
+ | Class::Accessor::Array   | 4         | 1.4                    | 28         | 2e-05   | 20      |
+ | perl -e1 (baseline)      | 2.6       | 0                      | 43         | 7.4e-06 | 20      |
  +--------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
